cwlVersion: v1.2
class: CommandLineTool
id: amplicon-architect
doc: "This tool prepares input for amplicon architect anaylsis"
requirements: 
  - class: ShellCommandRequirement
  - class: InlineJavascriptRequirement 
  - class: DockerRequirement
    dockerPull: 'jluebeck/prepareaa:v0.1203.10'
  - class: ResourceRequirement
    ramMin: 16000
    coresMin: $(inputs.threads)
  - class: InitialWorkDirRequirement
    listing:
      - $(inputs.data_repo)
      - entryname: setup_vars.sh
        entry: |-
          export AA_DATA_REPO=$(inputs.data_repo.path) \
          && mkdir licenses && cp $(inputs.mosek_license_file.path) licenses \
          && export MOSEKLM_LICENSE_FILE=$PWD/licenses;
          if [ ${ return inputs.ref_cache ? "REF_CACHE_YES" : null; } != null ];
          then
          tar -xzf ${ return inputs.ref_cache ? inputs.ref_cache.path : ''; } && export REF_CACHE="$PWD/ref/cache/%2s/%2s/%s"
          fi
  - class: EnvVarRequirement
    envDef:
      AA_SRC: '/home/programs/AmpliconArchitect-master/src'
baseCommand: []
arguments: 
  - position: 0
    shellQuote: false
    valueFrom: >-
      . ./setup_vars.sh
      && cp $(inputs.coverage_stats.path) $AA_DATA_REPO/coverage.stats
  - position: 1
    shellQuote: false
    valueFrom: >-
      && /home/programs/AmpliconArchitect-master/src/AmpliconArchitect.py
inputs:
  data_repo: { type: Directory, doc: "Un-tarred reference obtained from https://datasets.genepattern.org/?prefix=data/module_support_files/AmpliconArchitect/" }
  data_ref_version: { type: ['null', {type: enum, name: wgs_mode, symbols: ["GRCh38", "hg19", "GRCh37", "mm10", "GRCm38"]}], doc: "Genome version in data repo to use", default: "GRCh38", inputBinding: { position: 1, prefix: "--ref"} }
  bam: { type: File, doc: "tumor bam file", secondaryFiles: [{pattern: '^.bai', required: false}, {pattern: '.crai',
    required: false}], inputBinding: { position: 1, prefix: "--bam" } }
  downsample: { type: 'int?', doc: "Recommended for anaylsis", default: 10, inputBinding: { position: 1, prefix: "--downsample" } }
  output_basename: { type: 'string', inputBinding: { position: 1, prefix: "--out"} }
  threads: { type: 'int?', doc: 'Num threads to use', default: 8 }
  aa_bed: { type: File, doc: "Bed file from prepare-aa", inputBinding: { position: 1, prefix: "--bed"} }
  coverage_stats: { type: File, doc: "Coverage stats file generated by prepare-aa" }
  ref_cache: { type: 'File?', doc: "For cram input, provide tar ball of output of running misc/seq_cache_populate.pl from samtools on the reference fasta" }
  mosek_license_file: { type: File, doc: "This tool uses some software that requires a license file. You can get a personal or institutional one from https://www.mosek.com/license/request/." }
outputs:
  summary: 
    type: File
    outputBinding:
      glob: '*_summary.txt'
  graph:
    type: 'File[]'
    outputBinding:
      glob: '*_graph.txt'
  cycles:
    type: 'File[]'
    outputBinding:
      glob: '*_cycles.txt'
  sv_png:
    type: 'File[]'
    outputBinding:
      glob: '*.png'
  sv_pdf:
    type: 'File[]'
    outputBinding:
      glob: '*.pdf'

