#!/usr/bin/env cwl-runner
class: CommandLineTool
cwlVersion: v1.0
label: VcfTools
doc: |-
  NAME
  vcftools v0.1.16 − Utilities for the variant call format (VCF) and binary variant call format (BCF)

  SYNOPSIS
  vcftools [ --vcf FILE | --gzvcf FILE | --bcf FILE] [ --out OUTPUT PREFIX ] [ FILTERING OPTIONS ] [ OUTPUT OPTIONS ]

  DESCRIPTION
  vcftools is a suite of functions for use on genetic variation data in the form of VCF and BCF files. The tools provided will be used mainly to summarize data, run calculations on data, filter out data, and convert data into other useful file formats.

requirements:
- class: ShellCommandRequirement
- class: InlineJavascriptRequirement
- class: DockerRequirement
  dockerPull: biocontainers/vcftools:v0.1.16-1-deb_cv1

inputs:
- id: vcf
  label: vcf
  doc: |-
    This option defines the VCF file to be processed. VCFtools expects files in VCF format v4.0, v4.1 or v4.2. The latter two are supported  with  some  small limitations. If the user provides a dash character '-' as a file name, the program expects a VCF file to be piped in through standard in.
  type: File
  inputBinding:
    prefix: --vcf
- id: outputFilename
  label: outputFilename
  doc: |-
    <output_prefix>. This option defines the output filename prefix for all files generated by vcftools. For example, if <prefix> is set to output_filename, then all output files will be of the form output_filename.*** . If this option is omitted, all output files will have the prefix "out." in the current working directory.
  type:
  - string
  - 'null'
  default: generated
  inputBinding:
    prefix: --out
- id: removeFileteredAll
  label: removeFileteredAll
  doc: Removes all sites with a FILTER flag other than PASS.
  type:
  - boolean
  - 'null'
  inputBinding:
    prefix: --remove-filtered-all
    position: 1
    shellQuote: false
- id: recode
  label: recode
  doc: ''
  type:
  - boolean
  - 'null'
  inputBinding:
    prefix: --recode
    position: 1
    shellQuote: false
- id: recodeINFOAll
  label: recodeINFOAll
  doc: |-
    These options can be used with the above recode options to define an INFO key name to keep in the output  file.  This  option can be used multiple times to keep more of the INFO fields. The second option is used to keep all INFO values in the original file.
  type:
  - boolean
  - 'null'
  inputBinding:
    prefix: --recode-INFO-all
    position: 1
    shellQuote: false

outputs:
- id: out
  label: out
  type: File
  outputBinding:
    glob: $((inputs.outputFilename + ".recode.vcf"))
    outputEval: $((inputs.outputFilename.basename + ".recode.vcf"))
    loadContents: false
stdout: _stdout
stderr: _stderr

baseCommand:
- ''
- vcftools
arguments: []
id: VcfTools
